/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmcvew;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.ClientReceiverInterface;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.DynamicObject;
import de.bsvrz.dav.daf.main.config.MutableSet;
import de.bsvrz.dav.daf.main.config.MutableSetChangeListener;
import de.bsvrz.dav.daf.main.config.SystemObject;



/**
 * Klasse zum Verwalten der dynamischen Objekte vom Typ "typ.rdsMeldung". 
 * Die Klasse meldet sich auf nderung der dynamischen Menge RDS/TMC - Meldung an und verwaltet diese 
 * in einer Hashmap.
 * 
 * @author Dambach Werke GmbH
 * @version $Revision: 1.1 $ / $Date: 2008/10/29 12:09:03 $ / ($Author: Hilpp $)
 */
public class RdsMeldungsVerwaltung implements ClientReceiverInterface, MutableSetChangeListener
{
	/**
	 * bergebene Datenverteiler Verbindung
	 */
	private static ClientDavConnection m_connection;
	/**
	 * bergebenes Datenmodell
	 */
	private static DataModel m_dataModel;	
	/**
	 * Liste der aktuellen Engstellen
	 */
	private List<DynamicObject> m_listeMeldung;	
	/**
	 * Verkehrsmodellnetz.
	 */
	private ConfigurationObject m_verkehrsModellNetz;	

  
  /**
   * Hashmap mit den einzelnen Instanzen der von der RDS-Verwaltung gesendete Objekte
   * key = Pid des RdsMeldungsobjekts
   * value = Instanz der RdsMeldung
   */
	private HashMap<String, RdsMeldungsAuswertung> m_meldungsAuswertung = new HashMap<String, RdsMeldungsAuswertung>();
	
	/**
	 * Konstruktor der Klasse.
	 * Anmeldung auf nderung der dynamischen Menge RdsMeldung<br>
	 * Holen der aktuellen Objekte der dynamischen Menge<br>
	 * Anmeldung der Attributgruppenverwendungen<br>
	 * @param connection Datenverteilerverbindung
	 * @param netz Verkehrsmodellnetz
	 */
	public RdsMeldungsVerwaltung(ClientDavConnection connection, String netz )
	{
	  m_connection = connection;
	  m_dataModel = m_connection.getDataModel();
	  m_verkehrsModellNetz = (ConfigurationObject)m_dataModel.getObject(netz);
	  
	  m_listeMeldung = new ArrayList<DynamicObject>();
	  
  	  m_verkehrsModellNetz.getMutableSet("RDSMeldungen").addChangeListener(this);
	  
  	  rdsObjekteBestimmen();
	}

	/**
	 * Bestimmt die im Verkehrsmodellnetz aktuell vorhandenen RDS-Verwaltung.
	 */
	protected void rdsObjekteBestimmen()
	{ 
 	  if (m_verkehrsModellNetz == null)
  		return;
	  
  	  List liste = m_verkehrsModellNetz.getMutableSet("RDSMeldungen").getElements();
	     
  	  for (int i = 0; i < liste.size(); i++)
	    {
  		  DynamicObject obj = (DynamicObject)liste.get(i);
        rdsListeVerwalten(obj);  		
	    }
	}

	/**
	 * Methode liefert eine HashMap mit den aktiven Meldungsobjekten
	 * @return Objekt StauAuswertung
	 */
	
	public HashMap getRdsMeldung()
	{
		if( m_meldungsAuswertung.size() > 0 )
			return m_meldungsAuswertung;
		else
			return null;
	}
	
	/**
	 * Verwaltet die Liste der dynamischen RDS Objekte. In einer Liste werden alle aktiven 
	 * RDSobjekte gehalten. Werden neue RDSobjekte empfangen werden diese in die Liste
	 * eingefgt, werden RDSobjekte ungltig werden diese aus der Liste gelscht.
	 * @param obj Dynamisches Objekt RDSmeldungen
	 */
	private void rdsListeVerwalten(DynamicObject obj) 
	{
		if (obj == null)
			return;
		
		if (obj.isValid())
		{
			if (!m_listeMeldung.contains(obj))
			{
				m_listeMeldung.add(obj);
				m_meldungsAuswertung.put( obj.getPid(), new RdsMeldungsAuswertung (m_connection, obj.getPid()) );
      }
		}
		else
		{
			m_listeMeldung.remove(obj);
      
      if (m_meldungsAuswertung.containsKey( obj.getPid() ))
      {
    	m_meldungsAuswertung.get( obj.getPid() ).dispose();
    	m_meldungsAuswertung.remove( obj.getPid() );
      }
      
//			System.out.println("StauAuswertung " + obj.getPid() + " aus Liste gelscht");
		}	
	}

  /**
   * Update Methode des ClientReceiverInterface zum Empfang der "normalen" Daten
   * @param results beinhaltet die empfangenen Daten
   */
	public void update(ResultData results[])
	{
		for (int i = 0; i < results.length; i++)
		{
			ResultData data = results[i];
			
		}
	}

  /**
   * Update Methode des ClientReceiverInterface zum Empfang fr die dynamischen Objekte
   * @param set 			Menge der dynamischen Objekte
   * @param addedObjects  Dynamische Objekte die neu hinzugekommen sind
   * @param removedObjects  Dynamische Objekte die entfernt wurden
   */
   
	public void update(MutableSet set, SystemObject[] addedObjects, SystemObject[] removedObjects)
	{
		for (int i = 0; i < removedObjects.length; i++)
		{
		  DynamicObject obj = (DynamicObject) removedObjects[i];
      
          rdsListeVerwalten(obj);  		
		}

		for (int i = 0; i < addedObjects.length; i++)											
		{
			DynamicObject obj = (DynamicObject) addedObjects[i];

			rdsListeVerwalten(obj);  		
		}
	}
}
